@@ -1,4 +1,9 @@
+from __future__ import annotations
 import warnings
+import traceback
+from types import TracebackType
+from typing import Callable, Type
+
 from . import check_log
 from .check_log import log_failure
 
@@ -11,47 +16,54 @@ _stop_on_fail = False
 
 
 class CheckContextManager:
-    def __init__(self):
-        self.msg = None
+    def __init__(self) -> None:
+        self.msg: object = None
 
-    def __enter__(self):
+    def __enter__(self) -> "CheckContextManager":
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(
+        self,
+        exc_type: Type[BaseException] | None,
+        exc_val: BaseException | None,
+        exc_tb: TracebackType | None,
+    ) -> bool | None:
         __tracebackhide__ = True
         if exc_type is not None and issubclass(exc_type, AssertionError):
             if _stop_on_fail:
                 self.msg = None
-                return
+                return None
             else:
+                fmt_tb = traceback.format_exception(exc_type, exc_val, exc_tb)
                 if self.msg is not None:
-                    log_failure(f"{self.msg}\n{exc_val}")
+                    log_failure(f"{exc_val}, {self.msg}", tb=fmt_tb)
                 else:
-                    log_failure(exc_val)
+                    log_failure(exc_val, tb=fmt_tb)
                 self.msg = None
                 return True
         self.msg = None
+        return None
 
-    def __call__(self, msg=None):
+    def __call__(self, msg: object = None) -> "CheckContextManager":
         self.msg = msg
         return self
 
-    def set_no_tb(self):
+    def set_no_tb(self) -> None:
         warnings.warn(
             "set_no_tb() is deprecated; use set_max_tb(0)", DeprecationWarning
             )
         check_log._max_tb = 0
 
-    def set_max_fail(self, x):
+    def set_max_fail(self, x: int) -> None:
         check_log._max_fail = x
 
-    def set_max_report(self, x):
+    def set_max_report(self, x: int) -> None:
         check_log._max_report = x
 
-    def set_max_tb(self, x):
+    def set_max_tb(self, x: int) -> None:
         check_log._max_tb = x
 
-    def call_on_fail(self, func):
+    def call_on_fail(self, func: Callable[[str], None]) -> None:
         """Experimental feature - may change with any release"""
         check_log._fail_function = func
 
